aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--phpBB/config/profilefields.yml10
-rw-r--r--phpBB/includes/acp/acp_profile.php2
-rw-r--r--phpBB/includes/acp/acp_users.php2
-rw-r--r--phpBB/includes/functions_user.php2
-rw-r--r--phpBB/includes/ucp/ucp_pm_viewmessage.php2
-rw-r--r--phpBB/includes/ucp/ucp_profile.php2
-rw-r--r--phpBB/includes/ucp/ucp_register.php2
-rw-r--r--phpBB/memberlist.php4
-rw-r--r--phpBB/phpbb/profilefields/manager.php (renamed from phpBB/phpbb/profilefields/profilefields.php)2
-rw-r--r--phpBB/phpbb/profilefields/type/type_bool.php10
-rw-r--r--phpBB/phpbb/profilefields/type/type_date.php12
-rw-r--r--phpBB/phpbb/profilefields/type/type_dropdown.php14
-rw-r--r--phpBB/viewtopic.php2
13 files changed, 33 insertions, 33 deletions
diff --git a/phpBB/config/profilefields.yml b/phpBB/config/profilefields.yml
index 6c6ccedcea..8044bc8bc5 100644
--- a/phpBB/config/profilefields.yml
+++ b/phpBB/config/profilefields.yml
@@ -1,6 +1,6 @@
services:
- profilefields:
- class: \phpbb\profilefields\profilefields
+ profilefields.manager:
+ class: \phpbb\profilefields\manager
arguments:
- @auth
- @dbal.conn
@@ -30,7 +30,7 @@ services:
class: \phpbb\profilefields\type\type_bool
arguments:
- @profilefields.lang_helper
- - @profilefields
+ - @profilefields.manager
- @request
- @template
- @user
@@ -40,7 +40,7 @@ services:
profilefields.type.date:
class: \phpbb\profilefields\type\type_date
arguments:
- - @profilefields
+ - @profilefields.manager
- @request
- @template
- @user
@@ -51,7 +51,7 @@ services:
class: \phpbb\profilefields\type\type_dropdown
arguments:
- @profilefields.lang_helper
- - @profilefields
+ - @profilefields.manager
- @request
- @template
- @user
diff --git a/phpBB/includes/acp/acp_profile.php b/phpBB/includes/acp/acp_profile.php
index c37d501aac..2fa1f38bd3 100644
--- a/phpBB/includes/acp/acp_profile.php
+++ b/phpBB/includes/acp/acp_profile.php
@@ -50,7 +50,7 @@ class acp_profile
trigger_error($user->lang['NO_FIELD_ID'] . adm_back_link($this->u_action), E_USER_WARNING);
}
- $cp = $phpbb_container->get('profilefields');
+ $cp = $phpbb_container->get('profilefields.manager');
$this->type_collection = $phpbb_container->get('profilefields.type_collection');
// Build Language array
diff --git a/phpBB/includes/acp/acp_users.php b/phpBB/includes/acp/acp_users.php
index beb6fa1960..4153d78ed4 100644
--- a/phpBB/includes/acp/acp_users.php
+++ b/phpBB/includes/acp/acp_users.php
@@ -1344,7 +1344,7 @@ class acp_users
include($phpbb_root_path . 'includes/functions_user.' . $phpEx);
- $cp = $phpbb_container->get('profilefields');
+ $cp = $phpbb_container->get('profilefields.manager');
$cp_data = $cp_error = array();
diff --git a/phpBB/includes/functions_user.php b/phpBB/includes/functions_user.php
index b2cd911a0d..17cdd0ce39 100644
--- a/phpBB/includes/functions_user.php
+++ b/phpBB/includes/functions_user.php
@@ -276,7 +276,7 @@ function user_add($user_row, $cp_data = false)
{
$cp_data['user_id'] = (int) $user_id;
- $cp = $phpbb_container->get('profilefields');
+ $cp = $phpbb_container->get('profilefields.manager');
$sql = 'INSERT INTO ' . PROFILE_FIELDS_DATA_TABLE . ' ' .
$db->sql_build_array('INSERT', $cp->build_insert_sql_array($cp_data));
$db->sql_query($sql);
diff --git a/phpBB/includes/ucp/ucp_pm_viewmessage.php b/phpBB/includes/ucp/ucp_pm_viewmessage.php
index 78a0e010e6..119b84564a 100644
--- a/phpBB/includes/ucp/ucp_pm_viewmessage.php
+++ b/phpBB/includes/ucp/ucp_pm_viewmessage.php
@@ -61,7 +61,7 @@ function view_message($id, $mode, $folder_id, $msg_id, $folder, $message_row)
// Load the custom profile fields
if ($config['load_cpf_pm'])
{
- $cp = $phpbb_container->get('profilefields');
+ $cp = $phpbb_container->get('profilefields.manager');
$profile_fields = $cp->generate_profile_fields_template('grab', $author_id);
}
diff --git a/phpBB/includes/ucp/ucp_profile.php b/phpBB/includes/ucp/ucp_profile.php
index 672588c51f..2fdd4bc905 100644
--- a/phpBB/includes/ucp/ucp_profile.php
+++ b/phpBB/includes/ucp/ucp_profile.php
@@ -256,7 +256,7 @@ class ucp_profile
trigger_error('NO_AUTH_PROFILEINFO');
}
- $cp = $phpbb_container->get('profilefields');
+ $cp = $phpbb_container->get('profilefields.manager');
$cp_data = $cp_error = array();
diff --git a/phpBB/includes/ucp/ucp_register.php b/phpBB/includes/ucp/ucp_register.php
index 333aa2816f..cb5f96133a 100644
--- a/phpBB/includes/ucp/ucp_register.php
+++ b/phpBB/includes/ucp/ucp_register.php
@@ -76,7 +76,7 @@ class ucp_register
}
}
- $cp = $phpbb_container->get('profilefields');
+ $cp = $phpbb_container->get('profilefields.manager');
$error = $cp_data = $cp_error = array();
$s_hidden_fields = array();
diff --git a/phpBB/memberlist.php b/phpBB/memberlist.php
index 84fbb8218a..019b1873a0 100644
--- a/phpBB/memberlist.php
+++ b/phpBB/memberlist.php
@@ -617,7 +617,7 @@ switch ($mode)
$profile_fields = array();
if ($config['load_cpf_viewprofile'])
{
- $cp = $phpbb_container->get('profilefields');
+ $cp = $phpbb_container->get('profilefields.manager');
$profile_fields = $cp->generate_profile_fields_template('grab', $user_id);
$profile_fields = (isset($profile_fields[$user_id])) ? $cp->generate_profile_fields_template('show', false, $profile_fields[$user_id]) : array();
}
@@ -1554,7 +1554,7 @@ switch ($mode)
// Load custom profile fields
if ($config['load_cpf_memberlist'])
{
- $cp = $phpbb_container->get('profilefields');
+ $cp = $phpbb_container->get('profilefields.manager');
// Grab all profile fields from users in id cache for later use - similar to the poster cache
$profile_fields_cache = $cp->generate_profile_fields_template('grab', $user_list);
diff --git a/phpBB/phpbb/profilefields/profilefields.php b/phpBB/phpbb/profilefields/manager.php
index aec2756211..9f64e1dcf7 100644
--- a/phpBB/phpbb/profilefields/profilefields.php
+++ b/phpBB/phpbb/profilefields/manager.php
@@ -13,7 +13,7 @@ namespace phpbb\profilefields;
* Custom Profile Fields
* @package phpBB3
*/
-class profilefields
+class manager
{
/**
* Auth object
diff --git a/phpBB/phpbb/profilefields/type/type_bool.php b/phpBB/phpbb/profilefields/type/type_bool.php
index 68d17fb4cf..6b34d6923f 100644
--- a/phpBB/phpbb/profilefields/type/type_bool.php
+++ b/phpBB/phpbb/profilefields/type/type_bool.php
@@ -19,7 +19,7 @@ class type_bool extends type_base
/**
* Profile fields object
- * @var \phpbb\profilefields\profilefields
+ * @var \phpbb\profilefields\manager
*/
protected $profilefields;
@@ -45,16 +45,16 @@ class type_bool extends type_base
* Construct
*
* @param \phpbb\profilefields\lang_helper $lang_helper Profile fields language helper
- * @param \phpbb\profilefields\profilefields $profilefields Profile fields object
+ * @param \phpbb\profilefields\manager $manager Profile fields object
* @param \phpbb\request\request $request Request object
* @param \phpbb\template\template $template Template object
* @param \phpbb\user $user User object
* @param string $language_table Table where the language strings are stored
*/
- public function __construct(\phpbb\profilefields\lang_helper $lang_helper, \phpbb\profilefields\profilefields $profilefields, \phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
+ public function __construct(\phpbb\profilefields\lang_helper $lang_helper, \phpbb\profilefields\manager $manager, \phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
{
$this->lang_helper = $lang_helper;
- $this->profilefields = $profilefields;
+ $this->manager = $manager;
$this->request = $request;
$this->template = $template;
$this->user = $user;
@@ -88,7 +88,7 @@ class type_bool extends type_base
$options = array(
0 => array('TITLE' => $this->user->lang['FIELD_TYPE'], 'EXPLAIN' => $this->user->lang['BOOL_TYPE_EXPLAIN'], 'FIELD' => '<label><input type="radio" class="radio" name="field_length" value="1"' . (($field_data['field_length'] == 1) ? ' checked="checked"' : '') . ' onchange="document.getElementById(\'add_profile_field\').submit();" /> ' . $this->user->lang['RADIO_BUTTONS'] . '</label><label><input type="radio" class="radio" name="field_length" value="2"' . (($field_data['field_length'] == 2) ? ' checked="checked"' : '') . ' onchange="document.getElementById(\'add_profile_field\').submit();" /> ' . $this->user->lang['CHECKBOX'] . '</label>'),
- 1 => array('TITLE' => $this->user->lang['DEFAULT_VALUE'], 'FIELD' => $this->profilefields->process_field_row('preview', $profile_row)),
+ 1 => array('TITLE' => $this->user->lang['DEFAULT_VALUE'], 'FIELD' => $this->manager->process_field_row('preview', $profile_row)),
);
return $options;
diff --git a/phpBB/phpbb/profilefields/type/type_date.php b/phpBB/phpbb/profilefields/type/type_date.php
index 335a63b3f4..a71e6fde68 100644
--- a/phpBB/phpbb/profilefields/type/type_date.php
+++ b/phpBB/phpbb/profilefields/type/type_date.php
@@ -13,9 +13,9 @@ class type_date extends type_base
{
/**
* Profile fields object
- * @var \phpbb\profilefields\profilefields
+ * @var \phpbb\profilefields\manager
*/
- protected $profilefields;
+ protected $manager;
/**
* Request object
@@ -38,15 +38,15 @@ class type_date extends type_base
/**
* Construct
*
- * @param \phpbb\profilefields\profilefields $profilefields Profile fields object
+ * @param \phpbb\profilefields\manager $manager Profile fields object
* @param \phpbb\request\request $request Request object
* @param \phpbb\template\template $template Template object
* @param \phpbb\user $user User object
* @param string $language_table Table where the language strings are stored
*/
- public function __construct(\phpbb\profilefields\profilefields $profilefields, \phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
+ public function __construct(\phpbb\profilefields\manager $manager, \phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
{
- $this->profilefields = $profilefields;
+ $this->manager = $manager;
$this->request = $request;
$this->template = $template;
$this->user = $user;
@@ -87,7 +87,7 @@ class type_date extends type_base
}
$options = array(
- 0 => array('TITLE' => $this->user->lang['DEFAULT_VALUE'], 'FIELD' => $this->profilefields->process_field_row('preview', $profile_row)),
+ 0 => array('TITLE' => $this->user->lang['DEFAULT_VALUE'], 'FIELD' => $this->manager->process_field_row('preview', $profile_row)),
1 => array('TITLE' => $this->user->lang['ALWAYS_TODAY'], 'FIELD' => '<label><input type="radio" class="radio" name="always_now" value="1"' . (($s_checked) ? ' checked="checked"' : '') . ' onchange="document.getElementById(\'add_profile_field\').submit();" /> ' . $this->user->lang['YES'] . '</label><label><input type="radio" class="radio" name="always_now" value="0"' . ((!$s_checked) ? ' checked="checked"' : '') . ' onchange="document.getElementById(\'add_profile_field\').submit();" /> ' . $this->user->lang['NO'] . '</label>'),
);
diff --git a/phpBB/viewtopic.php b/phpBB/viewtopic.php
index 396de132cb..227cfdd029 100644
--- a/phpBB/viewtopic.php
+++ b/phpBB/viewtopic.php
@@ -1265,7 +1265,7 @@ $db->sql_freeresult($result);
// Load custom profile fields
if ($config['load_cpf_viewtopic'])
{
- $cp = $phpbb_container->get('profilefields');
+ $cp = $phpbb_container->get('profilefields.manager');
// Grab all profile fields from users in id cache for later use - similar to the poster cache
$profile_fields_tmp = $cp->generate_profile_fields_template('grab', $id_cache);
diff --git a/phpBB/phpbb/profilefields/type/type_dropdown.php b/phpBB/phpbb/profilefields/type/type_dropdown.php
index 5596e8f172..aee19fda30 100644
--- a/phpBB/phpbb/profilefields/type/type_dropdown.php
+++ b/phpBB/phpbb/profilefields/type/type_dropdown.php
@@ -19,9 +19,9 @@ class type_dropdown extends type_base
/**
* Profile fields object
- * @var \phpbb\profilefields\profilefields
+ * @var \phpbb\profilefields\manager
*/
- protected $profilefields;
+ protected $manager;
/**
* Request object
@@ -45,16 +45,16 @@ class type_dropdown extends type_base
* Construct
*
* @param \phpbb\profilefields\lang_helper $lang_helper Profile fields language helper
* @param \phpbb\profilefields\profilefields $profilefields Profile fields object
* @param \phpbb\request\request $request Request object
* @param \phpbb\template\template $template Template object
* @param \phpbb\user $user User object
* @param string $language_table Table where the language strings are stored
*/
- public function __construct(\phpbb\profilefields\lang_helper $lang_helper, \phpbb\profilefields\profilefields $profilefields, \phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
+ public function __construct(\phpbb\profilefields\lang_helper $lang_helper, \phpbb\profilefields\manager $manager, \phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
{
$this->lang_helper = $lang_helper;
- $this->profilefields = $profilefields;
+ $this->manager = $manager;
$this->request = $request;
$this->template = $template;
$this->user = $user;
@@ -91,8 +91,8 @@ class type_dropdown extends type_base
$profile_row[1]['field_default_value'] = $field_data['field_novalue'];
$options = array(
- 0 => array('TITLE' => $this->user->lang['DEFAULT_VALUE'], 'FIELD' => $this->profilefields->process_field_row('preview', $profile_row[0])),
- 1 => array('TITLE' => $this->user->lang['NO_VALUE_OPTION'], 'EXPLAIN' => $this->user->lang['NO_VALUE_OPTION_EXPLAIN'], 'FIELD' => $this->profilefields->process_field_row('preview', $profile_row[1])),
+ 0 => array('TITLE' => $this->user->lang['DEFAULT_VALUE'], 'FIELD' => $this->manager->process_field_row('preview', $profile_row[0])),
+ 1 => array('TITLE' => $this->user->lang['NO_VALUE_OPTION'], 'EXPLAIN' => $this->user->lang['NO_VALUE_OPTION_EXPLAIN'], 'FIELD' => $this->manager->process_field_row('preview', $profile_row[1])),
);
return $options;
@@ -45,16 +45,16 @@ class type_dropdown extends type_base
*
* @param \phpbb\profilefields\lang_helper $lang_helper Profile fields language helper
- * @param \phpbb\profilefields\profilefields $profilefields Profile fields object
+ * @param \phpbb\profilefields\manager $manager Profile fields object
* @param \phpbb\request\request $request Request object
* @param \phpbb\template\template $template Template object